package com.zd.laboratory.mapper;

import com.zd.laboratory.domain.LabSafeClasstype;

import java.util.List;

/**
 * 安全分级类型Mapper接口
 *
 * @author zd
 * @date 2021-12-18
 */
public interface LabSafeClasstypeMapper
{
    /**
     * 查询安全分级类型
     *
     * @param id 安全分级类型主键
     * @return 安全分级类型
     */
    public LabSafeClasstype selectLabSafeClasstypeById(Long id);

    /**
     * 查询安全分级类型列表
     *
     * @param labSafeClasstype 安全分级类型
     * @return 安全分级类型集合
     */
    public List<LabSafeClasstype> selectLabSafeClasstypeList(LabSafeClasstype labSafeClasstype);

    /**
     * 新增安全分级类型
     *
     * @param labSafeClasstype 安全分级类型
     * @return 结果
     */
    public int insertLabSafeClasstype(LabSafeClasstype labSafeClasstype);

    /**
     * 修改安全分级类型
     *
     * @param labSafeClasstype 安全分级类型
     * @return 结果
     */
    public int updateLabSafeClasstype(LabSafeClasstype labSafeClasstype);

    /**
     * 删除安全分级类型
     *
     * @param id 安全分级类型主键
     * @return 结果
     */
    public int deleteLabSafeClasstypeById(Long id);

    /**
     * 批量删除安全分级类型
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLabSafeClasstypeByIds(Long[] ids);
}
